==> fengoffice_1.7.5.zip: fengoffice/language/nl_nl/actions.php <==
<?php return array(
	'register' => 'Registreer',
	'login' => 'Inloggen',
	'logout' => 'Uitloggen',
	'hide welcome info' => '» Deze informatie permanent verbergen',
	'add company' => 'Bedrijf toevoegen',
	'edit company' => 'Bewerk bedrijfsgegevens',
	'delete company' => 'Verwijder bedrijf',
	'edit company logo' => 'Vernieuw logo',
	'delete company logo' => 'Verwijder logo',
	'add client' => 'Klant toevoegen',
	'edit client' => 'Bewerk klantgegevens',
	'delete client' => 'Verwijder klant',
	'add user' => 'Gebruiker toevoegen',
	'edit user' => 'Bewerk gebruikersgegevens',
	'delete user' => 'Verwijder gebruiker',
	'create user from contact' => 'Maak een gebruiker aan aan de hand van bestaande contactgegevens',
	'add group' => 'Gebruikersgroep toevoegen',
	'edit group' => 'Bewerk gebruikersgroep',
	'delete group' => 'Verwijder gebruikersgroep',
	'add project' => 'Werkomgeving toevoegen',
	'edit project' => 'Bewerk werkomgeving',
	'delete project' => 'Verwijder werkomgeving',
	'mark project as finished' => 'Markeer deze werkomgeving als gesloten',
	'mark project as active' => 'Markeer deze werkomgeving als actief',
	'add workspace' => 'Werkomgeving toevoegen',
	'edit workspace' => 'Bewerk werkomgeving',
	'delete workspace' => 'Verwijder werkomgeving',
	'mark workspace as finished' => 'Markeer deze werkomgeving als gesloten',
	'mark workspace as active' => 'Markeer deze werkomgeving als actief',
	'add message' => 'Notitie toevoegen',
	'add new message' => 'Nieuwe notitie toevoegen',
	'edit message' => 'Bewerk notitie',
	'delete message' => 'Verwijder notitie',
	'view message' => 'Bekijk notitie',
	'update message options' => 'Vernieuw opties',
	'subscribe to object' => 'Abonneer',
	'unsubscribe from object' => 'Zeg abonnement op',
	'add comment' => 'Geef commentaar',
	'edit comment' => 'Bewerk commentaar',
	'add task list' => 'Taak toevoegen',
	'edit task list' => 'Bewerk taak',
	'delete task list' => 'Verwijder taak',
	'reorder tasks' => 'Taken opnieuw sorteren',
	'reorder sub tasks' => 'Sub taken opnieuw sorteren',
	'copy task' => 'Kopieer deze taak',
	'copy milestone' => 'Kopieer deze mijlpaal',
	'add task' => 'Taak toevoegen',
	'add sub task' => 'Sub taak toevoegen',
	'edit task' => 'Bewerk taak',
	'delete task' => 'Verwijder taak',
	'mark task as completed' => 'Markeer deze taak als behandeld',
	'mark task as open' => 'Markeer deze taak als open',
	'add milestone' => 'Mijlpaal toevoegen',
	'edit milestone' => 'Bewerk mijlpaal',
	'delete milestone' => 'Verwijder mijlpaal',
	'add event' => 'Gebeurtenis toevoegen',
	'edit event' => 'Bewerk gebeurtenis',
	'delete event' => 'Verwijder gebeurtenis',
	'previous month' => 'Vorige maand',
	'next month' => 'Volgende maand',
	'previous week' => 'Vorige week',
	'next week' => 'Volgende week',
	'previous day' => 'Gisteren',
	'next day' => 'Morgen',
	'back to calendar' => 'Terug naar kalender',
	'back to day' => 'Terug naar dag',
	'pick a date' => 'Kies een datum',
	'month' => 'Maand',
	'week' => 'Week',
	'can edit company data' => 'Mag bedrijfs gegevens wijzigen',
	'can manage security' => 'Mag beveiliging beheren',
	'can manage workspaces' => 'Mag werkomgevingen beheren',
	'can manage configuration' => 'Mag configuratie beheren',
	'can manage contacts' => 'Mag contacten beheren',
	'group users' => 'Groepeer gebruikers',
	'update people' => 'Vernieuw',
	'remove user from project' => 'Verwijder gebruiker van deze werkomgeving',
	'remove company from project' => 'Verwijder bedrijf van project',
	'update profile' => 'Vernieuw profiel',
	'change password' => 'Verander wachtwoord',
	'update avatar' => 'Vernieuw gebruikersafbeelding',
	'delete current avatar' => 'Verwijder huidige gebruikersafbeelding',
	'add form' => 'Formulier toevoegen',
	'edit form' => 'Bewerk formulier',
	'delete form' => 'Verwijder formulier',
	'submit project form' => 'Verzend',
	'add file' => 'Bestand toevoegen',
	'edit file properties' => 'Bewerk eigenschappen van bestand
',
	'upload file' => 'Upload bestand',
	'create new revision' => 'Maak een nieuwe revisie',
	'add document' => 'Commentaar toevoegen',
	'save document' => 'Sla document op',
	'add spreadsheet' => 'Spreadsheet toevoegen',
	'add presentation' => 'Presentatie toevoegen ',
	'document' => 'Document',
	'spreadsheet' => 'Spreadsheet',
	'presentation' => 'presentatie',
	'new' => 'Nieuw',
	'upload' => 'Upload',
	'hide' => 'Verbergen',
	'new document' => 'Nieuw document',
	'new spreadsheet' => 'Nieuwe spreadsheet',
	'new presentation' => 'Nieuwe presentatie',
	'slideshow' => 'Dia voorstelling
',
	'revisions and comments' => 'Revisie en commentaar',
	'Save' => 'Opslaan',
	'all elements' => 'Alle elementen',
	'collapse all' => 'Invouwen',
	'expand all' => 'Uitvouwen',
	'properties' => 'Eigenschappen',
	'edit file' => 'Bewerk bestand',
	'edit document' => 'Bewerk document',
	'edit spreadsheet' => 'Bewerk spreadsheet',
	'edit presentation' => 'Bewerk presentatie',
	'play' => 'Afspelen',
	'queue' => 'Wachtrij',
	'delete file' => 'Verwijder bestand',
	'add folder' => 'Map toevoegen',
	'edit folder' => 'Bewerk map',
	'delete folder' => 'Verwijder map',
	'edit file revisions' => 'Bewerk revisie',
	'version' => 'Versie',
	'last modification' => 'Laatste modificatie',
	'link object' => 'Koppel object',
	'link objects' => 'Koppel objecten',
	'link more objects' => 'Koppel meer objecten',
	'unlink' => 'Ontkoppel',
	'unlink object' => 'Ontkoppel object',
	'unlink objects' => 'Ontkoppel objecten',
	'extract' => 'Uitpakken',
	'add files to zip' => 'Voeg bestanden toe aan het zip-je',
	'delete tag' => 'Verwijder label',
	'update permissions' => 'Vernieuw machtigingen',
	'edit permissions' => 'Bewerk machtigingen',
	'edit permissions explanation' => 'Vink de vakjes aan om gebruikers toegang voor de aangemaakte werkomgeving te verschaffen.',
	'save as new revision' => 'Sla op als nieuwe revisie',
	'save as' => 'Hernoem',
	'details' => 'Details',
	'view history for' => 'Bekijk de historie van',
	'view history' => 'Bekijk de historie',
	'edit preferences' => 'Bewerk voorkeuren',
	'view milestone' => 'Bekijk mijlpaal',
	'custom properties' => 'Aangepaste eigenschappen',
	'move to trash' => 'Gooi in de prullenbak',
	'restore from trash' => 'Herstellen uit de prullenbak',
	'delete permanently' => 'Verwijder definitief',
	'copy file' => 'Kopieer dit bestand',
	'open weblink' => 'Open weblink',
	'apply milestone to subtasks' => 'Pas mijlpaal toe op sub taken',
	'apply workspace to subtasks' => 'Pas werkomgeving toe op sub taken',
	'show all linked objects' => 'Toon alle gekoppelde objecten({0})',
	'archive' => 'Archiveren',
	'unarchive' => 'Dearchiveren ',
	'confirm archive selected objects' => 'Weet u zeker dat u de geselecteerde objecten wilt archiveren?',
	'confirm archive object' => 'Weet u zeker dat u het geselecteerde object wilt archiveren?',
	'confirm unarchive object' => 'Weet u zeker dat u het geselecteerde object wilt dearchiveren ?',
	'mark as unread' => 'Markeer als ongelezen',
	'mark as read' => 'Markeer als gelezen',
	'report as spam' => 'Spam',
	'not spam' => 'Geen spam',
	'show' => 'Toon',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/nl_nl/actions.php <==
<?php return array(
	'register' => 'Registreer',
	'login' => 'Inloggen',
	'logout' => 'Uitloggen',
	'hide welcome info' => '» Deze informatie permanent verbergen',
	'add company' => 'Bedrijf toevoegen',
	'edit company' => 'Bewerk bedrijfsgegevens',
	'delete company' => 'Verwijder bedrijf',
	'edit company logo' => 'Vernieuw logo',
	'delete company logo' => 'Verwijder logo',
	'add client' => 'Klant toevoegen',
	'edit client' => 'Bewerk klantgegevens',
	'delete client' => 'Verwijder klant',
	'add user' => 'Gebruiker toevoegen',
	'edit user' => 'Bewerk gebruikersgegevens',
	'delete user' => 'Verwijder gebruiker',
	'create user from contact' => 'Maak een gebruiker aan aan de hand van bestaande contactgegevens',
	'add group' => 'Gebruikersgroep toevoegen',
	'edit group' => 'Bewerk gebruikersgroep',
	'delete group' => 'Verwijder gebruikersgroep',
	'add project' => 'Werkomgeving toevoegen',
	'edit project' => 'Bewerk werkomgeving',
	'delete project' => 'Verwijder werkomgeving',
	'mark project as finished' => 'Markeer deze werkomgeving als gesloten',
	'mark project as active' => 'Markeer deze werkomgeving als actief',
	'add workspace' => 'Werkomgeving toevoegen',
	'edit workspace' => 'Bewerk werkomgeving',
	'delete workspace' => 'Verwijder werkomgeving',
	'mark workspace as finished' => 'Markeer deze werkomgeving als gesloten',
	'mark workspace as active' => 'Markeer deze werkomgeving als actief',
	'add message' => 'Notitie toevoegen',
	'add new message' => 'Nieuwe notitie toevoegen',
	'edit message' => 'Bewerk notitie',
	'delete message' => 'Verwijder notitie',
	'view message' => 'Bekijk notitie',
	'update message options' => 'Vernieuw opties',
	'subscribe to object' => 'Abonneer',
	'unsubscribe from object' => 'Zeg abonnement op',
	'add comment' => 'Geef commentaar',
	'edit comment' => 'Bewerk commentaar',
	'add task list' => 'Taak toevoegen',
	'edit task list' => 'Bewerk taak',
	'delete task list' => 'Verwijder taak',
	'reorder tasks' => 'Taken opnieuw sorteren',
	'reorder sub tasks' => 'Sub taken opnieuw sorteren',
	'copy task' => 'Kopieer deze taak',
	'copy milestone' => 'Kopieer deze mijlpaal',
	'add task' => 'Taak toevoegen',
	'add sub task' => 'Sub taak toevoegen',
	'edit task' => 'Bewerk taak',
	'delete task' => 'Verwijder taak',
	'mark task as completed' => 'Markeer deze taak als behandeld',
	'mark task as open' => 'Markeer deze taak als open',
	'add milestone' => 'Mijlpaal toevoegen',
	'edit milestone' => 'Bewerk mijlpaal',
	'delete milestone' => 'Verwijder mijlpaal',
	'add event' => 'Gebeurtenis toevoegen',
	'edit event' => 'Bewerk gebeurtenis',
	'delete event' => 'Verwijder gebeurtenis',
	'previous month' => 'Vorige maand',
	'next month' => 'Volgende maand',
	'previous week' => 'Vorige week',
	'next week' => 'Volgende week',
	'previous day' => 'Gisteren',
	'next day' => 'Morgen',
	'back to calendar' => 'Terug naar kalender',
	'back to day' => 'Terug naar dag',
	'pick a date' => 'Kies een datum',
	'month' => 'Maand',
	'week' => 'Week',
	'can edit company data' => 'Mag bedrijfs gegevens wijzigen',
	'can manage security' => 'Mag beveiliging beheren',
	'can manage workspaces' => 'Mag werkomgevingen beheren',
	'can manage configuration' => 'Mag configuratie beheren',
	'can manage contacts' => 'Mag contacten beheren',
	'group users' => 'Groepeer gebruikers',
	'update people' => 'Vernieuw',
	'remove user from project' => 'Verwijder gebruiker van deze werkomgeving',
	'remove company from project' => 'Verwijder bedrijf van project',
	'update profile' => 'Vernieuw profiel',
	'change password' => 'Verander wachtwoord',
	'update avatar' => 'Vernieuw avatar',
	'delete current avatar' => 'Verwijder huidige avatar',
	'add form' => 'Formulier toevoegen',
	'edit form' => 'Bewerk formulier',
	'delete form' => 'Verwijder formulier',
	'submit project form' => 'Verzend',
	'add file' => 'Bestand toevoegen',
	'edit file properties' => 'Bewerk eigenschappen van bestand
',
	'upload file' => 'Upload bestand',
	'create new revision' => 'Maak een nieuwe revisie',
	'add document' => 'Commentaar toevoegen',
	'save document' => 'Sla document op',
	'add spreadsheet' => 'Spreadsheet toevoegen',
	'add presentation' => 'Presentatie toevoegen ',
	'document' => 'Document',
	'spreadsheet' => 'Spreadsheet',
	'presentation' => 'presentatie',
	'new' => 'Nieuw',
	'upload' => 'Upload',
	'hide' => 'Verbergen',
	'new document' => 'Nieuw document',
	'new spreadsheet' => 'Nieuwe spreadsheet',
	'new presentation' => 'Nieuwe presentatie',
	'slideshow' => 'Dia voorstelling
',
	'revisions and comments' => 'Revisie en commentaar',
	'Save' => 'Opslaan',
	'all elements' => 'Alle elementen',
	'collapse all' => 'Invouwen',
	'expand all' => 'Uitvouwen',
	'properties' => 'Eigenschappen',
	'edit file' => 'Bewerk bestand',
	'edit document' => 'Bewerk document',
	'edit spreadsheet' => 'Bewerk spreadsheet',
	'edit presentation' => 'Bewerk presentatie',
	'play' => 'Afspelen',
	'queue' => 'Wachtrij',
	'delete file' => 'Verwijder bestand',
	'add folder' => 'Map toevoegen',
	'edit folder' => 'Bewerk map',
	'delete folder' => 'Verwijder map',
	'edit file revisions' => 'Bewerk revisie',
	'version' => 'Versie',
	'last modification' => 'Laatste modificatie',
	'link object' => 'Koppel object',
	'link objects' => 'Koppel objecten',
	'link more objects' => 'Koppel meer objecten',
	'unlink' => 'Ontkoppel',
	'unlink object' => 'Ontkoppel object',
	'unlink objects' => 'Ontkoppel objecten',
	'extract' => 'Uitpakken',
	'add files to zip' => 'Voeg bestanden toe aan het zip-je',
	'delete tag' => 'Verwijder label',
	'update permissions' => 'Vernieuw machtigingen',
	'edit permissions' => 'Bewerk machtigingen',
	'edit permissions explanation' => 'Vink de vakjes aan om gebruikers toegang voor de aangemaakte werkomgeving te verschaffen.',
	'save as new revision' => 'Sla op als nieuwe revisie',
	'save as' => 'Hernoem',
	'details' => 'Details',
	'view history for' => 'Bekijk de historie van',
	'view history' => 'Bekijk de historie',
	'edit preferences' => 'Bewerk voorkeuren',
	'view milestone' => 'Bekijk mijlpaal',
	'custom properties' => 'Aangepaste eigenschappen',
	'move to trash' => 'Gooi in de prullenbak',
	'restore from trash' => 'Herstellen uit de prullenbak',
	'delete permanently' => 'Verwijder definitief',
	'copy file' => 'Kopieer dit bestand',
	'open weblink' => 'Open weblink',
	'apply milestone to subtasks' => 'Pas mijlpaal toe op sub taken',
	'apply workspace to subtasks' => 'Pas werkomgeving toe op sub taken',
	'show all linked objects' => 'Toon alle gekoppelde objecten({0})',
	'archive' => 'Archiveren',
	'unarchive' => 'Dearchiveren ',
	'confirm archive selected objects' => 'Weet u zeker dat u de geselecteerde objecten wilt archiveren?',
	'confirm archive object' => 'Weet u zeker dat u het geselecteerde object wilt archiveren?',
	'confirm unarchive object' => 'Weet u zeker dat u het geselecteerde object wilt dearchiveren ?',
	'mark as unread' => 'Markeer als ongelezen',
	'mark as read' => 'Markeer als gelezen',
	'report as spam' => 'Spam',
	'not spam' => 'Geen spam',
); ?>
